@@ -98,6 +98,9 @@ class LocationInfo(BaseInheritInfo, Persistent, Contained):
 
     locations = FieldProperty(ILocationInfo['locations'])
 
+    def is_locatable(self):
+        return self.gps_location or self.forests or self.cities
+
     @volatile_property
     def get_forests_from_departments(self):
         return self.all_departments_forests or self.domanials_only or self.communals_only
@@ -314,6 +317,26 @@ class LocationInfo(BaseInheritInfo, Persistent, Contained):
     def update_gps_locations(self):
         self.locations = self.get_gps_locations()
 
+    def get_search_params(self):
+        if self.gps_location:
+            longitude, latitude = self.gps_location.wgs_coordinates
+            yield f'user_location={float(longitude)} {float(latitude)}'
+        if self.forests:
+            yield from (
+                f'user_location={id_foret}'
+                for id_foret in self.forests
+            )
+        if self.cities:
+            yield from (
+                f'user_location={code_insee}'
+                for code_insee in self.cities
+            )
+        if self.departments and (len(self.departments == 1)):
+            yield from (
+                f'user_location={code_dept}'
+                for code_dept in self.departments_index
+            )
+
 
 @subscriber(IObjectMovedEvent, context_selector=ILocationTarget)
 def handle_moved_location(event):
