@@ -504,6 +504,8 @@ class BaseFilterAggregationProcessor(BaseFilterProcessor):
                 pictogram = None
                 feature_info = IThesaurusTermFilterInfo(tag_object, None)
                 if feature_info is not None:
+                    if not feature_info.display_in_facets_list:
+                        continue
                     pictogram = feature_info.get_pictogram()
                 result.append({
                     'key': tag_object.label,
