@@ -4,7 +4,7 @@ from zope.schema import Bool, Choice
 
 from pyams_content.reference.pictograms.interfaces import PICTOGRAM_VOCABULARY
 
-from pyams_content import _
+from onf_website import _
 
 
 class IThesaurusTermFilterInfo(Interface):
