@@ -37,5 +37,19 @@ class IForestTable(IReferenceTable):
                            value_type=Bool(required=True,
                                            default=True),
                            required=False)
+    
+    hunting_displays = Dict(title=_("Hunting calendar displays"),
+                            description=_("You can disable display of all hunting calendars for "
+                                          "a specific owner category by just unchecking their label"),
+                            key_type=Choice(vocabulary=FOREST_OWNERS_CATEGORIES),
+                            value_type=Bool(required=True,
+                                            default=False),
+                            required=False)
 
     visible_owners_ids = Attribute("Visible owners categories IDs")
+
+    def get_published_forests(self):
+        """Get list of published forests"""
+        
+    def get_published_hunting_calendars(self):
+        """Get list of published hunting calendars forests"""
