@@ -10,29 +10,25 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-__docformat__ = 'restructuredtext'
-
-
-# import standard library
 import re
 
-# import interfaces
-from onf_website.reference.insee.model.interfaces import ICodeLibelle, IPays, ICodePostal, IRegion, IArrondissement, \
-    IDepartementModel, IDepartement, ICanton, ICommuneModel, ICommune
+from geoalchemy2 import Geometry
+from sqlalchemy import Column, Integer, Unicode
+from sqlalchemy.ext.declarative import declared_attr
+from sqlalchemy.orm import joinedload, relation
+from sqlalchemy.schema import ForeignKey, ForeignKeyConstraint, UniqueConstraint
+from sqlalchemy.sql.expression import and_, or_
+from zope.interface import implementer, provider
 from zope.schema.interfaces import ITitledTokenizedTerm
 
-# import packages
-from geoalchemy2 import Geometry
+from onf_website.reference.insee.model.interfaces import IArrondissement, ICanton, ICodeLibelle, ICodePostal, ICommune, \
+    ICommuneModel, IDepartement, IDepartementModel, IPays, IRegion
 from pyams_alchemy import Base
 from pyams_alchemy.engine import get_user_session
 from pyams_alchemy.mixin import DynamicSchemaMixin
 from pyams_utils.unicode import translate_string
-from sqlalchemy import Column, Integer, Unicode
-from sqlalchemy.ext.declarative import declared_attr
-from sqlalchemy.orm import relation, joinedload
-from sqlalchemy.schema import ForeignKey, ForeignKeyConstraint, UniqueConstraint
-from sqlalchemy.sql.expression import and_, or_
-from zope.interface import implementer, provider
+
+__docformat__ = 'restructuredtext'
 
 
 PARENT_SCHEMA = 'insee'
@@ -283,6 +279,9 @@ class Region(DynamicSchemaMixin, Base):
 
 # Table 'DEPARTEMENT'
 
+REG_DEPT_CODE = re.compile(r'\d{2,3}')
+
+
 @provider(IDepartementModel)
 @implementer(IDepartement, ITitledTokenizedTerm)
 class Departement(DynamicSchemaMixin, Base):
@@ -371,6 +370,17 @@ class Departement(DynamicSchemaMixin, Base):
         return ()
 
 
+class DepartementGeom(DynamicSchemaMixin, Base):
+    """Content class for departments with geometry"""
+
+    __tablename__ = 'insee_departement_geom'
+    __schema__ = PARENT_SCHEMA
+
+    gid = Column(Integer, primary_key=True)
+    code = Column('insee_dept', Unicode(3), ForeignKey(Departement.dep), unique=True)
+    geom = Column(Geometry('MULTIPOLYGON', 4326))
+
+
 # Table 'ARRONDISSEMENTS'
 
 @implementer(IArrondissement)
@@ -638,6 +648,10 @@ Departement.ref_cheflieu = relation(Commune,
                                     uselist=False)
 Departement.ref_tncc = relation(CodeTNCC)
 
+Departement.ref_geom = relation(DepartementGeom,
+                                primaryjoin=Departement.dep==DepartementGeom.code,
+                                uselist=False)
+
 Arrondissement.ref_region = relation(Region)
 Arrondissement.ref_departement = relation(Departement)
 Arrondissement.ref_cheflieu = relation(Commune,
