@@ -60,10 +60,18 @@ def site_container_restrictions_factory(context):
 @factory_config(ISiteManagerUniverseInfo)
 class SiteManagerUniverseInfo(Persistent):
     """Site manager universe info"""
-    
+
     universe = FieldProperty(ISiteManagerUniverseInfo['universe'])
-    
-    
+
+    def get_universe(self, visible_only=True):
+        universe = self.universe
+        if universe is None:
+            return None
+        if (not visible_only) or universe.visible:
+            return universe
+        return None
+
+
 @adapter_config(required=ISiteManager,
                 provides=ISiteManagerUniverseInfo)
 @adapter_config(required=ISiteRoot,
