@@ -26,3 +26,6 @@ class ISiteManagerUniverseInfo(Interface):
                       description=_("Select the universe associated with this site"),
                       vocabulary='ONF universe',
                       required=False)
+
+    def get_universe(self, visible_only=True):
+        """Get associated universe object, only if visible is argument is True"""
