@@ -10,10 +10,13 @@
 # FOR A PARTICULAR PURPOSE.
 #
 
-__docformat__ = 'restructuredtext'
-
 from zope.interface import Interface
 
+from pyams_default_theme.layer import IPyAMSDefaultLayer
+from pyams_template.template import layout_config
+
+__docformat__ = 'restructuredtext'
+
 
 ONF_API_SKIN_NAME = 'ONF API skin'
 
@@ -28,3 +31,8 @@ class IBodyClass(Interface):
 
 class IMainClass(Interface):
     """HTML #main class interface"""
+
+
+@layout_config(template='templates/inner-layout.pt', layer=IPyAMSDefaultLayer)
+class IInnerView(Interface):
+    """Inner view marker interface"""
