@@ -103,13 +103,14 @@
 				}
 				ONF.search.updateUrlWithCheckedFilters();
 			},
+
 			redirectToUrl: function () {
 				const $select = $(this);
 				const selectedUrl = $select.val();
 				console.log("select", selectedUrl)
 				window.location.href = selectedUrl;
-
 			},
+
 			updateUrlWithCheckedFilters: function () {
 				var urlParams = new URLSearchParams(window.location.search);
 				var filterTypes = new Set($('input[name="filter"], select[name="filter"], button[name="filter"]').map(function () {
@@ -298,12 +299,9 @@
 				}
 
 				$('button[name="filter"]').each(function () {
-
 					$(this).attr('aria-pressed', false);
-
 				});
 
-
 				ONF.search.updateUrlWithCheckedFilters();
 			},
 
@@ -401,6 +399,63 @@
 			}
 		},
 
+		/**
+		 * Near-me management
+		 */
+		pdcm: {
+
+			openPopup: function (evt) {
+				const
+					body = $('body'),
+					source = $(evt.currentTarget),
+					target = source.data('onf-pdcm-target'),
+					popupOverlay = $('<div>').addClass('pdcm-overlay');
+				if (target) {
+					$('<iframe>').addClass('pdcm-frame')
+							.attr('id', 'pdcm-frame')
+							.attr('src', target)
+							.appendTo(popupOverlay);
+					popupOverlay.appendTo(body);
+					body.addClass('with-pdcm-overlay');
+				}
+			},
+
+			closePopup: function(evt) {
+				const
+					body = $('body', window.parent.document),
+					overlay = $('.pdcm-overlay', body);
+				overlay.remove();
+				body.removeClass('with-pdcm-overlay');
+			},
+
+			openHelp: function(evt) {
+				$('.pdcm-help').addClass('is-open');
+			},
+
+			closeHelp: function(evt) {
+				$('.pdcm-help').removeClass('is-open');
+			},
+
+			enableAreaFilter: function (evt) {
+				var searchForm = $('form[id="recherche-filters"]'),
+					location = $('input[name="user_location"]', searchForm);
+				if (location.exists()) {
+					$('.opsmap__area_filter').removeClass('hidden');
+				}
+			},
+
+			applyAreaFilter: function (evt) {
+				var searchForm = $('form[id="recherche-filters"]'),
+					location = $('input[name="user_location"]', searchForm);
+				if (location.exists()) {
+					var map = $('.ams-map').data('leafmap'),
+						geo_center = map.getCenter();
+					location.val(`${geo_center.lng} ${geo_center.lat}`);
+					searchForm.submit();
+				}
+			}
+		},
+
 		/**
 		 * Zabuto calendar plugin for hunting calendars
 		 */
